==> clean_android_design-0.0.172.tar.gz: lib/src/structure/icon_scaffold_menu_button_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class IconScaffoldMenuButtonWidget extends StatelessWidget {
  final IconData icon;
  final Text text;
  final GestureTapCallback onTap;
  final String tooltip;
  final bool disabled;

  const IconScaffoldMenuButtonWidget({
    Key key,
    this.icon,
    this.text,
    this.onTap,
    this.tooltip,
    this.disabled = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Tooltip(
        message: tooltip,
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: 5),
          height: 50,
          child: Material(
            color: CleanAndroidDesignDefaultColors.background,
            borderRadius: BorderRadius.circular(10),
            child: InkWell(
              borderRadius: BorderRadius.circular(10),
              onTap: onTap,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  Icon(
                    icon,
                    color: disabled
                        ? CleanAndroidDesignDefaultColors.defaultColor
                            .withOpacity(0.6)
                        : CleanAndroidDesignDefaultColors.defaultColor,
                  ),
                  DefaultTextStyle(
                      style: TextStyles.textStyleSize(13).copyWith(
                          color: disabled
                              ? CleanAndroidDesignDefaultColors.defaultColor
                                  .withOpacity(0.6)
                              : null),
                      child: text)
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> clean_android_design-0.1.0.tar.gz: lib/src/structure/icon_scaffold_menu_button_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class IconScaffoldMenuButtonWidget extends StatelessWidget {
  final IconData? icon;
  final Text? text;
  final GestureTapCallback? onTap;
  final String? tooltip;
  final bool disabled;

  const IconScaffoldMenuButtonWidget({
    Key? key,
    this.icon,
    this.text,
    this.onTap,
    this.tooltip,
    this.disabled = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Tooltip(
        message: tooltip!,
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: 5),
          height: 50,
          child: Material(
            color: CleanAndroidDesignDefaultColors.background,
            borderRadius: BorderRadius.circular(10),
            child: InkWell(
              borderRadius: BorderRadius.circular(10),
              onTap: onTap,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  Icon(
                    icon,
                    color: disabled
                        ? CleanAndroidDesignDefaultColors.defaultColor!
                            .withOpacity(0.6)
                        : CleanAndroidDesignDefaultColors.defaultColor,
                  ),
                  DefaultTextStyle(
                      style: TextStyles.textStyleSize(13).copyWith(
                          color: disabled
                              ? CleanAndroidDesignDefaultColors.defaultColor!
                                  .withOpacity(0.6)
                              : null),
                      child: text!)
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
